@@ -653,6 +653,9 @@ class DataFrame(metaclass=DataFrameMeta):
         # lazy operations if possible. They can manually call .collect() if needed
         return self._underlying
 
+    def to_pyarrow(self) -> pyarrow.Table:
+        return self.to_polars().collect().to_arrow()
+
     def to_pandas(self) -> pd.DataFrame:
         """Get the underlying dataframe as a Pandas DataFrame."""
         # For pandas, the columns should be the Features, not the root fqns
