@@ -872,10 +872,12 @@ class StreamResolver(Resolver[P, T]):
     def __call__(self, *args: P.args, **kwargs: P.kwargs) -> T:
         raw_result = self.fn(*args, **kwargs)
         if self.window_index is not None and isinstance(raw_result, str) and str(args[self.window_index]) in raw_result:
-            raw_result = query_as_feature_formatted(
-                formatted_query=raw_result,
-                expected_features=[s.name for s in self.output_features],
-                table=args[self.window_index],
+            raw_result = DataFrame(
+                query_as_feature_formatted(
+                    formatted_query=raw_result,
+                    fqn_to_name={s.root_fqn: s.name for s in self.output_features},
+                    table=args[self.window_index],
+                )
             )
 
         return raw_result
