@@ -1,7 +1,5 @@
 from dataclasses import dataclass
-from typing import Any, List, Optional, Sequence, Type
-
-from pydantic.main import BaseModel
+from typing import Any, List, Optional, Sequence
 
 
 @dataclass
