@@ -1,11 +1,9 @@
-import os
 import typing
 from typing import Mapping, Optional, Sequence, Union
 
 import sqlalchemy
 from polars import from_arrow
 from sqlalchemy import text
-from sqlalchemy.engine import result
 from sqlalchemy.sql import selectable
 
 from chalk.clogging import chalk_logger
@@ -60,7 +58,18 @@ class StringChalkQuery(StringChalkQueryProtocol):
         self._finalizer = Finalizer.All
         return self
 
-    def incremental(self, *, incremental_column: str, lookback_period: Duration = "0s", mode: str = "row"):
+    def incremental(
+        self, *, incremental_column: Optional[str] = None, lookback_period: Duration = "0s", mode: str = "row"
+    ):
+        if mode in {"row", "group"} and incremental_column is None:
+            raise ValueError(f"incremental mode set to '{mode}' but no 'incremental_column' argument was passed.")
+
+        if mode == "parameter" and incremental_column is not None:
+            raise ValueError(
+                f"incremental mode set to '{mode}' but 'incremental_column' argument was passed."
+                + " Please view documentation for proper usage."
+            )
+
         self._finalizer = Finalizer.All
         self._incremental_settings = IncrementalSettings(
             lookback_period=lookback_period, incremental_column=incremental_column, mode=mode
