@@ -19,11 +19,9 @@ class WindowedInstance(Generic[T]):
 
 
 class WindowedMeta(type, Generic[T]):
-    _kind: Type[T]
-
     def __getitem__(cls, underlying: Type[T]) -> "Windowed[Type[T]]":
-        cls._kind = underlying
         return Windowed(
+            kind=underlying,
             buckets=[],
             mode="tumbling",
             description=None,
@@ -89,10 +87,14 @@ class Windowed(Generic[T], metaclass=WindowedMeta):
     def buckets_seconds(self) -> Set[int]:
         return set(int(parse_chalk_duration(bucket).total_seconds()) for bucket in self._buckets)
 
-    def to_feature(
-        self,
-        bucket: Optional[Union[int, str]],
-    ):
+    def set_kind(self, kind: Optional[Type[T]]) -> None:
+        if kind is not None:
+            self._kind = kind
+
+    def get_kind(self) -> Optional[Type[T]]:
+        return getattr(self, "_kind", None)
+
+    def to_feature(self, bucket: Optional[Union[int, str]]):
         from chalk.features import Feature
 
         assert self._name is not None
@@ -156,7 +158,9 @@ class Windowed(Generic[T], metaclass=WindowedMeta):
         max_length: Optional[int],
         contains: Optional[T],
         dtype: Optional[Union[Type[pl.DataType], pl.DataType]],
+        kind: Optional[Type[T]],
     ):
+        self.set_kind(kind=kind)
         self._name: Optional[str] = None
         self._buckets = buckets
         self._mode = mode
@@ -224,4 +228,5 @@ def windowed(
         max_length=max_length,
         contains=contains,
         dtype=dtype,
+        kind=None,
     )
