@@ -33,6 +33,13 @@ class StreamFeaturesWindow:
     child: ChildWindow = has_one(lambda: StreamFeaturesWindow.child_id == ChildWindow.id)
 
 
+@features
+class WindowType:
+    uid: str = feature(primary=True)
+    str_window: Windowed[str] = windowed("10m")
+    int_window: Windowed[int] = windowed("10m")
+
+
 @online
 def with_children(
     r: StreamFeaturesWindow.scalar_feature(window="10m"),
@@ -43,6 +50,11 @@ def with_children(
     return ""
 
 
+def test_windowed_underlying_type():
+    assert unwrap_feature(WindowType.str_window).typ.underlying._kind == str
+    assert unwrap_feature(WindowType.int_window).typ.underlying._kind == int
+
+
 def test_has_one_windows():
     assert resolver(with_children).inputs[0].root_fqn == "stream_features_window.scalar_feature__600__"
     assert resolver(with_children).inputs[1].root_fqn == "stream_features_window.child.childfeat__1200__"
